<?php
/** كوردي (عەرەبی)‏ (كوردي (عەرەبی)‏)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Arastein
 * @author Asoxor
 * @author Bonevarluri
 * @author George Animal
 * @author Marmzok
 * @author Muhammed taha
 */

$fallback = 'ckb';

$rtl = true;

$digitTransformTable = [
	'0' => '٠', # &#x0660;
	'1' => '١', # &#x0661;
	'2' => '٢', # &#x0662;
	'3' => '٣', # &#x0663;
	'4' => '٤', # &#x0664;
	'5' => '٥', # &#x0665;
	'6' => '٦', # &#x0666;
	'7' => '٧', # &#x0667;
	'8' => '٨', # &#x0668;
	'9' => '٩', # &#x0669;
	'.' => '٫', # &#x066b; wrong table ?
	',' => '٬', # &#x066c;
];
